/* --------------------------------------------------------------------
 * chgnam.c - Change a user's full name
 *
 * Written by Glenn Scott
 * UCLA Honors and Undergraduate Programs / Info Services
 * glenn@hup.ucla.edu
 *
 * Released to Public Domain with NO WARRANTY whatsoever.
 *
 * Requires Netware C Interface Library for DOS v1.2 or above
 * 9 Feb 92
 *
 * Abstract:  Changes the IDENTIFICATION property for the user object
 * in the bindery.  If the IDENTIFICATION property does not exist
 * (it isn't automatically created by SYSCON when you create a new
 * user) then CHGNAM attempts to create the property with the proper
 * flags and security and write the full name.
 *
 * Errors are reported as hex error codes.  Refer to Netware System
 * Calls documentation, C Interface Library documentation, or a
 * suitable third party book for explanations.
 * 
 *
 */

/* --------------------------------------------------------------------- */

#include <nit.h>
#include <niterror.h>
#include <stdio.h>

void main( int argc, char *argv[] )
{
   void        usage();
   int         logName( char *, char * );
   int         nRet;

   if ( !GetDefaultConnectionID() )
      {
         printf("This program requires Novell Netware 2.1x or higher.\n");
         exit(1);
      }

   if ( argc < 3 )
      {
         usage();
         exit( 1 );
      }

   nRet = logName( argv[1], argv[2] );

   if ( nRet == 0xfb )      /* No such property; was never created */
      {
         nRet = CreateProperty( argv[1], OT_USER, "IDENTIFICATION",  
                              BF_ITEM | BF_STATIC,
                              BS_SUPER_WRITE | BS_LOGGED_READ );
         if (nRet != SUCCESSFUL)
            {
               printf("Error creating IDENTIFICATION property, code: 0x%x\n", nRet);
               exit(1);
            }
         printf("Created IDENTIFICATION property for user %s\n", argv[2]);
         nRet = logName( argv[1], argv[2] );
      }

   if ( nRet != SUCCESSFUL)
      {
         printf("Error writing property value, code: 0x%x\n", nRet);
         exit(1);
      }

   exit( 0 );
}

/* --------------------------------------------------------------------- */

void usage()
{
  printf("CHGNAM - Change full name of a user from the DOS command line.\n");
  printf("Usage:  chgnam <user> \"New full name\"\n");
  return;
}

/* --------------------------------------------------------------------- */

int logName( char *user, char *name )
{
   return WritePropertyValue( user, OT_USER, "IDENTIFICATION", 1, name, 0 );
}

/* --------------------------------------------------------------------- */
